from typing import Literal

Scale = Literal[
    '0',
    'x-0',
    'y-0',
    '50',
    'x-50',
    'y-50',
    '75',
    'x-75',
    'y-75',
    '90',
    'x-90',
    'y-90',
    '95',
    'x-95',
    'y-95',
    '100',
    'x-100',
    'y-100',
    '105',
    'x-105',
    'y-105',
    '110',
    'x-110',
    'y-110',
    '125',
    'x-125',
    'y-125',
    '150',
    'x-150',
    'y-150',
]
